v0.3.0
=======
- added functions
    * :func:`rohub.ros_export_to_rocrate`
    * :func:`rohub.show_user_id`
    * ros_add_author (renamed in :doc:`v1.0.0.post1`)
    * ros_show_authors (renamed in :doc:`v1.0.0.post1`)
    * ros_add_contributor (renamed in :doc:`v1.0.0.post1`)
    * ros_show_contributors (renamed in :doc:`v1.0.0.post1`)
    * ros_add_copyright (renamed in :doc:`v1.0.0.post1`)
    * ros_show_copyright (renamed in :doc:`v1.0.0.post1`)
    * :func:`rohub.ros_add_funding`
    * ros_show_funding (renamed in :doc:`v1.0.2`)
    * zenodo_show_funders (renamed in :doc:`v1.0.0.post1`)
    * zenodo_show_grants (renamed in :doc:`v1.0.0.post1`)
    * ros_add_license (renamed in :doc:`v1.0.0.post1`)
    * show_available_licenses (renamed in :doc:`v1.0.0.post1`)
    * ros_show_license (renamed in :doc:`v1.0.0.post1`)